# UserRolesForAnOrg

The roles for a user
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_id** | **str** | Unique identifier | [optional] 
**org_id** | **str** | Unique identifier | [optional] 
**application** | **str** | The application the user has a role for | [optional] 
**role** | **str** | The role the user has for the given application | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


